#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Copyright 2020 University of Liège
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Dummy test
# Adrien Crovato

import fpm
import tbox
import tbox.gmsh as gmsh
from fwk.testing import *
from fwk.coloring import ccolors

def main():
    # timer
    tms = fpm.Timers()
    tms['total'].start()
    # mesh
    print(ccolors.ANSI_BLUE + 'PyMeshing...' + ccolors.ANSI_RESET)
    pars = {'spn' : 5, 'nC' : 80, 'nS' : 10}
    msh = gmsh.MeshLoader('../models/n0012.geo', __file__).execute(**pars)
    # problem
    pbl = fpm.Problem(msh, 0, 0, 5., 1., 0., 0., 0.)
    wing = fpm.Body(msh, 'wing', ['te'], 5)
    pbl.add(wing)
    print(pbl)
    # end timer
    tms['total'].stop()
    print(ccolors.ANSI_BLUE + 'PyTiming...' + ccolors.ANSI_RESET)
    print(tms)

    # test
    print(ccolors.ANSI_BLUE + 'PyTesting...' + ccolors.ANSI_RESET)
    tests = CTests()
    tests.run()
    
    # eof
    print('')

if __name__ == '__main__':
    main()

